@@ -1,12 +1,12 @@
 package Class::Type::Enum;
 # ABSTRACT: Build Enum-like classes
-$Class::Type::Enum::VERSION = '0.003';
+$Class::Type::Enum::VERSION = '0.004';
 
 use strict;
 use warnings;
 
 use Function::Parameters ':strict';
-use List::Util v1.33;
+use List::Util 1.33;
 use Scalar::Util qw(blessed);
 use Class::Method::Modifiers qw(install_modifier);
 
@@ -159,7 +159,7 @@ Class::Type::Enum - Build Enum-like classes
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
